@@ -1,11 +1,12 @@
-﻿using System;
-using Xunit;
+using System;
+using NUnit.Framework;
 
-namespace XUnitTestProjectTemplate
+namespace NUnitTestProjectTemplate
 {
+  [TestFixture]
   public class Tests
   {
-    [Fact]
+    [Test]
     public void Test1()
     {
       /*caret*/Assert.True(true);
